@@ -66,23 +66,26 @@ class MainBaseHandler(tornado.web.RequestHandler):
     def _handle_missing_params(self, missing):
         self.error(400, 'Missing required parameter(s) ({0})'.format(', '.join(missing)))
 
-    # def _handle_request_exception(self, e):
-    #     self._error = True
-    #     raise e
-        # if isinstance(e, tornado.web.HTTPError):
-        #     response = e.log_message
-        #     code = e.status_code
-        # elif isinstance(e, ApiError):
-        #     response = e.message
-        #     code = e.code
-        # else:
-        #     code = 500
-        #     response = str(e)
-        #     
-        # # TODO: add some logging here
-        # # TODO: if in debug mode, raise all exceptions
-        #     
-        # return self._respond((code, response))
+    def _handle_request_exception(self, e):
+        self._error = True
+
+        if settings.debug:
+            raise e
+
+        if isinstance(e, tornado.web.HTTPError):
+            response = e.log_message
+            code = e.status_code
+        elif isinstance(e, ApiError):
+            response = e.message
+            code = e.code
+        else:
+            code = 500
+            response = str(e)
+
+        # TODO: add some logging here
+        # TODO: if in debug mode, raise all exceptions
+
+        return self._respond((code, response))
 
 
     ##################################################
@@ -198,7 +201,7 @@ class MainBaseHandler(tornado.web.RequestHandler):
     def decode_arguments(self, val):
         single = False
         if not isinstance(val, (list, dict)):
-            val = [va]
+            val = [val]
             single = True
 
         dict_ = False
